﻿
using System;
using System.Text.RegularExpressions;
using System.Drawing;
using Wisej.Web;

namespace Wisej.DGVConditionalFormatting
{
	public partial class Page1 : Page
	{
		public Page1()
		{
			InitializeComponent();
		}

		private void Page1_Load(object sender, EventArgs e)
		{
			this.dataGridView1.RowCount = 10;

			this.dataGridView2.RowCount = 10;
			foreach (DataGridViewRow r in this.dataGridView2.Rows)
			{
				r[1].Value = "Lorem ipsum dolor sit amet, consectetur adipiscing elit.";
			}
		}

		private void dataGridView1_CellFormatting(object sender, DataGridViewCellFormattingEventArgs e)
		{
			// When formatting column 1, change the background color
			// of the cell if the value of the checkbox in column 0 is true.

			if (e.ColumnIndex == 1)
			{
				var grid = (DataGridView)sender;
				if (Object.Equals(grid[0, e.RowIndex].Value, true))
				{
					e.CellStyle.BackColor = Color.Yellow;
				}
				else
				{
					e.CellStyle.BackColor = Color.Empty;
				}
			}
		}

		private void dataGridView1_CellValueChanged(object sender, DataGridViewCellEventArgs e)
		{
			// Update the row when the value of column 0 changes.
			//
			// NOTE: RowIndex may be -1 when setting the text of the column header
			// cell, which is RowIndex = -1.

			if (e.ColumnIndex == 0 && e.RowIndex > -1)
			{
				var grid = (DataGridView)sender;
				grid.Rows[e.RowIndex].Update();
			}
		}

		private void dataGridView2_CellValueChanged(object sender, DataGridViewCellEventArgs e)
		{
			if (e.ColumnIndex == 0 && e.RowIndex > -1)
			{
				var grid = (DataGridView)sender;

				// NOTE: highlight the text in column 1 (AllowHtml = true is already set in the designer).
				// grid.Columns[1].AllowHtml = true;

				var textInColumn1 = (string)grid[1, e.RowIndex].Value ?? "";
				var textToHighlight = (string)grid[0, e.RowIndex].Value ?? "";
				
				// remove previous html formatting.
				textInColumn1 = Regex.Replace(textInColumn1, @"<[^>]*>", String.Empty);
				
				// bold and big all matching text.
				if (textToHighlight != "")
				{
					textInColumn1 = textInColumn1.Replace(textToHighlight, "<b><big>" + textToHighlight + "</big></b>");

					// change the background color of column 1 (alternative method to handling CellFormatting).
					grid[1, e.RowIndex].Style.BackColor = Color.LightGreen;
				}
				else
				{
					// change the background color of column 1 (alternative method to handling CellFormatting).
					grid[1, e.RowIndex].Style.BackColor = Color.Empty;
				}

				// update the text.
				grid[1, e.RowIndex].Value = textInColumn1;
			}
		}
	}
}
